==> nuxtjs-node6-1.1.1.tgz: package/lib/builder/webpack/postcss.js <==
'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const { existsSync } = require('fs');
const { resolve } = require('path');
const { cloneDeep } = require('lodash');
const { isPureObject } = require('../../common/utils');

module.exports = function postcssConfig() {
  let config = cloneDeep(this.options.build.postcss);

  /* istanbul ignore if */
  if (!config) {
    return false;
  }

  // Search for postCSS config file and use it if exists
  // https://github.com/michael-ciniawsky/postcss-load-config
  for (let dir of [this.options.srcDir, this.options.rootDir]) {
    for (let file of ['postcss.config.js', '.postcssrc.js', '.postcssrc', '.postcssrc.json', '.postcssrc.yaml']) {
      if (existsSync(resolve(dir, file))) {
        const postcssConfigPath = resolve(dir, file);
        return {
          sourceMap: this.options.build.cssSourceMap,
          config: {
            path: postcssConfigPath
          }
        };
      }
    }
  }

  // Normalize
  if (Array.isArray(config)) {
    config = { plugins: config };
  }

  // Apply default plugins
  if (isPureObject(config)) {
    config = (0, _assign2.default)({
      useConfigFile: false,
      sourceMap: this.options.build.cssSourceMap,
      plugins: {
        // https://github.com/postcss/postcss-import
        'postcss-import': {
          root: this.options.rootDir,
          path: [this.options.srcDir, this.options.rootDir, ...this.options.modulesDir]
        },

        // https://github.com/postcss/postcss-url
        'postcss-url': {},

        // http://cssnext.io/postcss
        'postcss-cssnext': {}
      }
    }, config);
  }

  // Map postcss plugins into instances on object mode once
  if (isPureObject(config) && isPureObject(config.plugins)) {
    config.plugins = (0, _keys2.default)(config.plugins).map(p => {
      const plugin = require(this.nuxt.resolvePath(p));
      const opts = config.plugins[p];
      if (opts === false) return; // Disabled
      const instance = plugin(opts);
      return instance;
    }).filter(e => e);
  }

  return config;
};

==> nuxtjs-node6-1.4.100.tgz: package/lib/builder/webpack/postcss.js <==
'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const { existsSync } = require('fs');
const { resolve, join } = require('path');
const { cloneDeep } = require('lodash');
const { isPureObject } = require('../../common/utils');
const createResolver = require('postcss-import-resolver');

module.exports = function postcssConfig() {
  let config = cloneDeep(this.options.build.postcss);

  /* istanbul ignore if */
  if (!config) {
    return false;
  }

  // Search for postCSS config file and use it if exists
  // https://github.com/michael-ciniawsky/postcss-load-config
  for (let dir of [this.options.srcDir, this.options.rootDir]) {
    for (let file of ['postcss.config.js', '.postcssrc.js', '.postcssrc', '.postcssrc.json', '.postcssrc.yaml']) {
      if (existsSync(resolve(dir, file))) {
        const postcssConfigPath = resolve(dir, file);
        return {
          sourceMap: this.options.build.cssSourceMap,
          config: {
            path: postcssConfigPath
          }
        };
      }
    }
  }

  // Normalize
  if (Array.isArray(config)) {
    config = { plugins: config };
  }

  // Apply default plugins
  if (isPureObject(config)) {
    config = (0, _assign2.default)({
      useConfigFile: false,
      sourceMap: this.options.build.cssSourceMap,
      plugins: {
        // https://github.com/postcss/postcss-import
        'postcss-import': {
          resolve: createResolver({
            alias: {
              '~': join(this.options.srcDir),
              '~~': join(this.options.rootDir),
              '@': join(this.options.srcDir),
              '@@': join(this.options.rootDir)
            },
            modules: [this.options.srcDir, this.options.rootDir, ...this.options.modulesDir]
          })
        },

        // https://github.com/postcss/postcss-url
        'postcss-url': {},

        // http://cssnext.io/postcss
        'postcss-cssnext': {}
      }
    }, config);
  }

  // Map postcss plugins into instances on object mode once
  if (isPureObject(config) && isPureObject(config.plugins)) {
    config.plugins = (0, _keys2.default)(config.plugins).map(p => {
      const plugin = require(this.nuxt.resolvePath(p));
      const opts = config.plugins[p];
      if (opts === false) return; // Disabled
      const instance = plugin(opts);
      return instance;
    }).filter(e => e);
  }

  return config;
};
